@@ -56,7 +56,8 @@ enum connect_return_codes {
 	CONN_REF_BAD_ID,
 	CONN_REF_SERVER_NOAVAIL,
 	CONN_REF_BAD_LOGIN,
-	CONN_REF_NO_AUTH
+	CONN_REF_NO_AUTH,
+	CONN_REF_BAD_TLS
 };
 
 /* unique naming for userdata metatables */
@@ -236,7 +237,7 @@ static int ctx_will_set(lua_State *L)
 		payload = lua_tolstring(L, 3, &payloadlen);
 	};
 
-	int qos = luaL_optint(L, 4, 0);
+	int qos = luaL_optinteger(L, 4, 0);
 	bool retain = lua_toboolean(L, 5);
 
 	int rc = mosquitto_will_set(ctx->mosq, topic, payloadlen, payload, qos, retain);
@@ -261,6 +262,20 @@ static int ctx_login_set(lua_State *L)
 	return mosq__pstatus(L, rc);
 }
 
+static int ctx_tls_set(lua_State *L)
+{
+	ctx_t *ctx = ctx_check(L, 1);
+	const char *cafile = luaL_optstring(L, 2, NULL);
+	const char *capath = luaL_optstring(L, 3, NULL);
+	const char *certfile = luaL_optstring(L, 4, NULL);
+	const char *keyfile = luaL_optstring(L, 5, NULL);
+
+	// the last param is a callback to a function that asks for a passphrase for a keyfile
+	// our keyfiles should NOT have a passphrase
+	int rc = mosquitto_tls_set(ctx->mosq, cafile, capath, certfile, keyfile, 0);
+	return mosq__pstatus(L, rc);
+}
+
 static int ctx_connect(lua_State *L)
 {
 	ctx_t *ctx = ctx_check(L, 1);
@@ -311,7 +326,7 @@ static int ctx_publish(lua_State *L)
 		payload = lua_tolstring(L, 3, &payloadlen);
 	};
 
-	int qos = luaL_optint(L, 4, 0);
+	int qos = luaL_optinteger(L, 4, 0);
 	bool retain = lua_toboolean(L, 5);
 
 	int rc = mosquitto_publish(ctx->mosq, &mid, topic, payloadlen, payload, qos, retain);
@@ -329,7 +344,7 @@ static int ctx_subscribe(lua_State *L)
 	ctx_t *ctx = ctx_check(L, 1);
 	int mid;
 	const char *sub = luaL_checkstring(L, 2);
-	int qos = luaL_optint(L, 3, 0);
+	int qos = luaL_optinteger(L, 3, 0);
 
 	int rc = mosquitto_subscribe(ctx->mosq, &mid, sub, qos);
 
@@ -360,8 +375,8 @@ static int ctx_unsubscribe(lua_State *L)
 static int mosq_loop(lua_State *L, bool forever)
 {
 	ctx_t *ctx = ctx_check(L, 1);
-	int timeout = luaL_optint(L, 2, -1);
-	int max_packets = luaL_optint(L, 3, 1);
+	int timeout = luaL_optinteger(L, 2, -1);
+	int max_packets = luaL_optinteger(L, 3, 1);
 	int rc;
 	if (forever) {
 		rc = mosquitto_loop_forever(ctx->mosq, timeout, max_packets);
@@ -418,7 +433,7 @@ static int ctx_socket(lua_State *L)
 static int ctx_loop_read(lua_State *L)
 {
 	ctx_t *ctx = ctx_check(L, 1);
-	int max_packets = luaL_optint(L, 2, 1);
+	int max_packets = luaL_optinteger(L, 2, 1);
 
 	int rc = mosquitto_loop_read(ctx->mosq, max_packets);
 	return mosq__pstatus(L, rc);
@@ -427,7 +442,7 @@ static int ctx_loop_read(lua_State *L)
 static int ctx_loop_write(lua_State *L)
 {
 	ctx_t *ctx = ctx_check(L, 1);
-	int max_packets = luaL_optint(L, 2, 1);
+	int max_packets = luaL_optinteger(L, 2, 1);
 
 	int rc = mosquitto_loop_write(ctx->mosq, max_packets);
 	return mosq__pstatus(L, rc);
@@ -483,6 +498,10 @@ static void ctx_on_connect(
 		case CONN_REF_NO_AUTH:
 			str = "connection refused - not authorised";
 			break;
+
+		case CONN_REF_BAD_TLS:
+			str = "connection refused - TLS error";
+			break;
 	}
 
 	lua_rawgeti(ctx->L, LUA_REGISTRYINDEX, ctx->on_connect);
@@ -607,7 +626,7 @@ static int ctx_callback_set(lua_State *L)
 	if (lua_isstring(L, 2)) {
 		callback_type = callback_type_from_string(lua_tostring(L, 2));
 	} else {
-		callback_type = luaL_checkint(L, 2);
+		callback_type = luaL_checkinteger(L, 2);
 	}
 
 	if (!lua_isfunction(L, 3)) {
@@ -728,6 +747,7 @@ static const struct luaL_Reg ctx_M[] = {
 	{"will_set",		ctx_will_set},
 	{"will_clear",		ctx_will_clear},
 	{"login_set",		ctx_login_set},
+	{"tls_set",		ctx_tls_set},
 	{"connect",			ctx_connect},
 	{"connect_async",	ctx_connect_async},
 	{"reconnect",		ctx_reconnect},
